#ifndef PrintPreviewDialog_p_h
#define PrintPreviewDialog_p_h

// $Id: PrintPreviewDialog_p.h,v 1.3 2012/07/10 19:54:52 hpereira Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
****************************************************************************/

#include "BasePrintHelper.h"
#include "CustomDialog.h"

#include <QtCore/QMap>
#include <QtGui/QIntValidator>
#include <QtGui/QLabel>
#include <QtGui/QLineEdit>
#include <QtGui/QMenuBar>
#include <QtGui/QPrintPreviewWidget>
#include <QtGui/QToolButton>

namespace PRINT
{

    //! handles page orientation and page mode
    class OptionMenu: public QMenuBar, public Counter
    {

        Q_OBJECT

        public:

        //! constructor
        OptionMenu( QWidget* );

        //! destructor
        virtual ~OptionMenu( void )
        {}

        signals:
        void orientationChanged( QPrinter::Orientation );
        void pageModeChanged( BasePrintHelper::PageMode );

        protected slots:

        //! orientation changed
        void _setOrientation( QAction* );

        //! page mode
        void _setPageMode( QAction* );

        private:

        //! actions maps
        typedef QMap<QAction*, QPrinter::Orientation> OrientationActionMap;
        OrientationActionMap orientationActions_;

        //! actions map
        typedef QMap<QAction*, BasePrintHelper::PageMode> PageModeActionMap;
        PageModeActionMap pageModeActions_;

    };

    //! handles page navigation
    class NavigationWidget: public QWidget, public Counter
    {

        Q_OBJECT

        public:

        //! constructor
        NavigationWidget( QWidget* );

        //! destructor
        virtual ~NavigationWidget( void )
        {}

        int pages( void )
        { return pages_; }

        //! set page
        void setPage( int );

        //! event filter
        bool eventFilter( QObject*, QEvent* );

        public slots:

        //! set pages
        void setPages( int );

        signals:

        //! new page selected
        void pageChanged( int );

        protected slots:

        //! previous page
        void _previousPage( void );

        //! next page
        void _nextPage( void );

        //! update page
        void _updatePage( void );

        //! update buttons
        void _updateButtons( void );

        private:

        //! number of pages
        int pages_;

        //! editor
        QLineEdit* editor_;

        //! previous page button
        QToolButton* previousPageButton_;

        //! next page button
        QToolButton* nextPageButton_;

        //! label
        QLabel* label_;

        //! valudator
        QIntValidator validator_;

    };

}

#endif
