
// $Id: Cache.cpp,v 1.7 2012/09/05 17:14:15 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Debug.h"
#include "Cache.h"
#include "XmlDef.h"
#include "XmlError.h"

#include <QtXml/QDomDocument>
#include <QtXml/QDomElement>

//____________________________________________________________________________
bool Cache::read( File file )
{

  Debug::Throw( "Cache::read.\n" );
  if( !file.isEmpty() ) file_ = file;
  if( file_.isEmpty() ) return false;

  // parse the file
  QFile in( file_ );
  if ( !in.open( QIODevice::ReadOnly ) )
  {
    Debug::Throw( "Cache::read - cannot open file.\n" );
    return false;
  }

  // dom document
  QDomDocument document;
  XmlError error( file_ );
  if ( !document.setContent( &in, &error.error(), &error.line(), &error.column() ) ) {
    in.close();
    Debug::Throw() << error << endl;
    return false;
  }

  QDomElement doc_element = document.documentElement();
  QDomNode node = doc_element.firstChild();
  for(QDomNode node = doc_element.firstChild(); !node.isNull(); node = node.nextSibling() )
  {

    QDomElement element = node.toElement();
    if( element.isNull() ) continue;

    // special options
    if( element.tagName() == XML::FILEINFO_CACHE ) fileInfoCache_ = FileInfoCache( element );
    else if( element.tagName() == XML::REVISION_CACHE ) revisionCache_ = RevisionCache( element );
    else Debug::Throw() << "Cache::read - unrecognized tag " << element.tagName() << endl;

  }

  return true;
}

//____________________________________________________________________________
bool Cache::write( File file ) const
{

  if( file.isEmpty() ) file = file_;
  if( file.isEmpty() ) return false;

  // output file
  QFile out( file );
  if( !out.open( QIODevice::WriteOnly ) ) return false;

  // create document
  QDomDocument document;

  // create main element
  QDomElement top = document.appendChild( document.createElement( XML::CACHE ) ).toElement();
  top.appendChild( fileInfoCache().domElement( document ) );
  top.appendChild( revisionCache().domElement( document ) );

  out.write( document.toByteArray() );
  out.close();

  return true;
}
