// $Id: DefaultOptions.h,v 1.27 2012/09/05 22:08:37 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA	02111-1307 USA
*
*
*******************************************************************************/

#include "CvsCommandModel.h"
#include "File.h"
#include "FileInfoModel.h"
#include "FileSelectionFrame.h"
#include "LogDialog.h"
#include "XmlOptions.h"
#include "Util.h"

//_____________________________________________________
//! default options installer
void installDefaultOptions( void )
{

    // set options default values
    XmlOptions::get().setAutoDefault( true );
    XmlOptions::get().set( "DB_SIZE", "30" );
    XmlOptions::get().set( "ICON_PIXMAP", Option( ":/icon.png" , "application icon") );
    XmlOptions::get().set( "MAIN_WINDOW_HEIGHT", "500" );
    XmlOptions::get().set( "MAIN_WINDOW_WIDTH", "700" );

    XmlOptions::get().set( "SHOW_NAVIGATOR", "1" );
    XmlOptions::get().set( "USE_TRUNCATION", "1" );

    XmlOptions::get().set( "SHOW_COMMAND_LIST", "0" );
    XmlOptions::get().set( "SHOW_LOG", "0" );
    XmlOptions::get().set( "SHOW_TOOLTIPS", "0" );
    XmlOptions::get().set( "SHOW_HIDDEN_FILES", "0" );

    // verbosity
    XmlOptions::get().set( "VERBOSITY", LogDialog::VERBOSITY_LOW );

    // toolbars
    XmlOptions::get().set( "NAVIGATION_TOOLBAR", Option( "1" , "toolbar visibility" ) );
    XmlOptions::get().set( "CVS_REMOTE_TOOLBAR", Option( "1" , "toolbar visibility" ) );
    XmlOptions::get().set( "CVS_LOCAL_TOOLBAR", Option( "1" , "toolbar visibility" ) );

    XmlOptions::get().set( "NAVIGATION_TOOLBAR_LOCATION", Option( "top" , "toolbar location" ) );
    XmlOptions::get().set( "CVS_TOOLBAR_LOCATION", Option( "top" , "toolbar location" ) );

    // mask
    XmlOptions::get().set<unsigned int>( "FILE_LIST_MASK", (1<<FileInfoModel::FILE) | (1<<FileInfoModel::SIZE) );
    XmlOptions::get().set<unsigned int>( "CVS_COMMAND_LIST_MASK", (1<<CvsCommandModel::NAME) | (1<<CvsCommandModel::PATH) );

    // view mode
    XmlOptions::get().set<unsigned int>( "VIEW_MODE", FileSelectionFrame::ICONS );

    // cache
    XmlOptions::get().set( "LIMIT_REVISION_CACHE", "0" );
    XmlOptions::get().set( "REVISION_CACHE_SIZE", "5" );

    XmlOptions::get().set( "LIMIT_FILEINFO_CACHE", "0" );
    XmlOptions::get().set( "FILEINFO_CACHE_SIZE", "5" );

    // pixmap size
    XmlOptions::get().set( "ICON_VIEW_PIXMAP_SIZE", 48 );

    // cvs root
    XmlOptions::get().set( "DEFAULT_CVSROOT", Util::env( "CVSROOT","" ) );

    // non recordable options
    XmlOptions::get().set( "APP_NAME", Option( "CVSWATCH", Option::NONE ) );
    XmlOptions::get().set( "DB_FILE", Option( File( ".cvswatch_db" ).addPath( Util::home() ), Option::NONE ) );
    XmlOptions::get().set( "CACHE_FILE", Option( File( ".cvswatch_cache" ).addPath( Util::home() ), Option::NONE ) );
    XmlOptions::get().set( "HELP_FILE", Option( File( "/.cvswatch_help" ).addPath( Util::home() ), Option::NONE ) );
    XmlOptions::get().set( "RC_FILE", Option( File(".cvswatchrc").addPath( Util::home() ), Option::NONE ) );
    XmlOptions::get().setAutoDefault( false );

};
