// $Id: FileInfoCacheDialog.cpp,v 1.8 2012/09/04 11:06:07 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA   02111-1307 USA
*
*
*******************************************************************************/
/*! FileInfoModel::List( cache.begin(), cache.end() )
\file FileInfoCacheDialog.cpp
\brief displays all run-time options
\author Hugo Pereira
\version $FileInfo: 1.1 $
\date $Date: 2012/09/04 11:06:07 $
*/

#include "Application.h"
#include "FileInfoCacheDialog.h"
#include "Singleton.h"
#include "TreeView.h"

#include <QtGui/QPushButton>
#include <QtGui/QLabel>
#include <QtGui/QLayout>

//__________________________________________________________________________
FileInfoCacheDialog::FileInfoCacheDialog( QWidget* parent ):
CustomDialog( parent, CloseButton )
{

    Debug::Throw( "FileInfoCacheDialog::FileInfoCacheDialog.\n" );
    setWindowTitle( "File Information - Cvswatch" );
    setOptionName( "REVISION_CACHE_DIALOG" );

    // create list
    mainLayout().addWidget( list_ = new TreeView( this ) );
    _list().setModel( &model_ );
    _list().setRootIsDecorated( true );
    _list().setOptionName( "REVISION_CACHE_LIST" );

}

//__________________________________________________________________________
void FileInfoCacheDialog::setCache( const FileInfoCache& cache )
{

    Debug::Throw( "FileInfoCacheDialog::setCache.\n" );

    // busy
    Singleton::get().application<Application>()->busy();
    FileInfoModel::List files;
    foreach( FileInfo fileInfo, cache )
    {
        fileInfo.update();
        files << fileInfo;
    }
    Singleton::get().application<Application>()->idle();

    model_.set( files );
    _list().resizeColumns();

}

