#ifndef MainWindow_h
#define MainWindow_h

// $Id: MainWindow.h,v 1.23 2012/09/05 22:08:37 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "BaseMainWindow.h"
#include "Cache.h"
#include "Counter.h"
#include "CvsCommand.h"
#include "Debug.h"
#include "FileRecord.h"
#include "Revision.h"
#include "TextEditor.h"

#include <QtCore/QBasicTimer>
#include <QtCore/QTimerEvent>
#include <QtGui/QAction>

class CvsCommandDialog;
class FileSelectionFrame;
class LogDialog;
class StatusBar;
class RevisionFrame;
class Menu;

//! cvs log revision frame view
class MainWindow: public BaseMainWindow, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    MainWindow( QWidget *parent = 0 );

    //! menu
    Menu& menu( void ) const
    { return *menu_; }

    //! info list
    FileSelectionFrame& selectionFrame( void ) const
    { return *fileSelectionFrame_; }

    //! info list
    RevisionFrame& revisionFrame( void ) const
    { return *revisionFrame_; }

    //! editor
    TextEditor& commentsEditor( void ) const
    { return *commentsEditor_; }

    //! command list
    CvsCommandDialog& commandDialog( void ) const
    { return *commandDialog_; }

    //! log dialog
    LogDialog& logDialog( void ) const
    { return *logDialog_; }

    //!@name actions
    //@{

    //! reload action
    QAction& reloadAction( void ) const
    { return *reloadAction_; }

    //! open
    QAction& openAction( void ) const
    { return *openAction_; }

    //! toggle command frame
    QAction& showCommandDialogAction( void ) const
    { return *showCommandDialogAction_; }

    //! toggle log visibility
    QAction& showLogDialogAction( void ) const
    { return *showLogDialogAction_; }

    //! file info cache
    QAction& fileInfoCacheAction( void ) const
    { return *fileInfoCacheAction_; }

    //! revision cache
    QAction& revisionCacheAction( void ) const
    { return *revisionCacheAction_; }

    //@}

    public slots:

    //! display cvs revisions for a given file
    void open( FileRecord record = FileRecord() );

    //! clear cache
    void clearCache( void );

    protected:

    //! resize event
    virtual void timerEvent( QTimerEvent* );

    //! close window event handler
    void closeEvent( QCloseEvent* );

    private slots:

    //! update configuration
    void _updateConfiguration( void );

    //! save configuration
    void _saveConfiguration( void );

    //! reload selection frame using file editor
    void _reload( void );

    //! select file from FileSelectionFrame
    void _setFile( File );

    //! display revision comments
    void _displayComments( Revision revision )
    { commentsEditor().setPlainText( revision.comments() ); }

    //! update status bar from current command
    void _updateStatusBar( CvsCommand );

    //! toggle command frame visibility
    void _showCommandDialog( void );

    //! command dialog hidden
    void _commandDialogHidden( void );

    //! toggle log visibility
    void _showLogDialog( void );

    //! log dialog hidden
    void _logDialogHidden( void );

    //! show file info cache
    void _showFileInfoCache( void );

    //! show revision cache
    void _showRevisionCache( void );

    //! splitter moved
    void _splitterMoved( void );

    private:

    //! install actions
    void _installActions( void );

    //! revisions and fileList cache
    Cache cache_;

    //! resize timer
    QBasicTimer resizeTimer_;

    //!@name constituting widgets
    //@{

    //! menu
    Menu* menu_;

    //! directory tree navigation
    FileSelectionFrame* fileSelectionFrame_;

    //! list of log revisions
    RevisionFrame* revisionFrame_;

    //! edit frame to display description comments
    TextEditor* commentsEditor_;

    //! command list
    CvsCommandDialog* commandDialog_;

    //! log
    LogDialog* logDialog_;

    //! state frame
    StatusBar* statusbar_;

    //! command list size
    QSize commandDialogSize_;

    //@}

    //!@name actions
    //@{

    //! reload
    QAction* reloadAction_;

    //! open
    QAction* openAction_;

    //! toggle command frame action
    QAction* showCommandDialogAction_;

    //! toggle log action
    QAction* showLogDialogAction_;

    //! file info cache action
    QAction* fileInfoCacheAction_;

    //! revision cache action
    QAction* revisionCacheAction_;

    //@}

};

#endif
