// $Id: RevisionCacheDialog.cpp,v 1.8 2012/02/20 20:49:45 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY;  without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA   02111-1307 USA
*
*
*******************************************************************************/
/*!
\file RevisionCacheDialog.cpp
\brief displays all run-time options
\author Hugo Pereira
\version $Revision: 1.8 $
\date $Date: 2012/02/20 20:49:45 $
*/

#include "RevisionCacheDialog.h"
#include "TreeView.h"

#include <QtGui/QPushButton>
#include <QtGui/QLabel>
#include <QtGui/QLayout>

//__________________________________________________________________________
RevisionCacheDialog::RevisionCacheDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{

    Debug::Throw( "RevisionCacheDialog::RevisionCacheDialog.\n" );
    setWindowTitle( "Revisions - Cvswatch" );
    setOptionName( "REVISION_CACHE_DIALOG" );

    // create list
    mainLayout().addWidget( list_ = new TreeView( this ) );
    _list().setModel( &model_ );
    _list().setRootIsDecorated( true );
    _list().setOptionName( "REVISION_CACHE_LIST" );

}

//__________________________________________________________________________
void RevisionCacheDialog::setCache( const RevisionCache& cache )
{

    Debug::Throw( "RevisionCacheDialog::setCache.\n" );

    RevisionCacheModel::List revisions;
    for( RevisionCache::const_iterator iter = cache.begin(); iter != cache.end(); ++iter )
    {
        for( Revision::List::const_iterator revIter = iter.value().begin(); revIter != iter.value().end(); ++revIter )
        { revisions << RevisionPair( iter.key(), *revIter ); }
    }

    model_.add( revisions );
    _list().resizeColumns();

}

