#ifndef RevisionModel_h
#define RevisionModel_h

// $Id: RevisionModel.h,v 1.9 2012/09/04 12:30:31 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    RevisionModel.h
\brief   Stores ftp commands for display in lists
\author  Hugo Pereira
\version $Revision: 1.9 $
\date    $Date: 2012/09/04 12:30:31 $
*/

#include "Counter.h"
#include "ListModel.h"
#include "Revision.h"

//! Job model. Stores job information for display in lists
class RevisionModel : public ListModel<Revision>, public Counter
{

    public:

    //! constructor
    RevisionModel(QObject *parent = 0);

    //! destructor
    virtual ~RevisionModel()
    {}

    //! number of columns
    enum { nColumns = 4 };

    //! column type enumeration
    enum ColumnType
    {
        REVISION,
        DATE,
        AUTHOR,
        COMMENT
    };

    //!@name methods reimplemented from base class
    //@{

    //! data
    virtual QVariant data(const QModelIndex &index, int role) const;

    //! header data
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    //! number of columns for a given index
    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
    { return nColumns; }

    //@}

    protected:

    //! sort
    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder );

    private:


    //! used to sort IconCaches
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //! constructor
        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
            ItemModel::SortFTor( type, order )
        {}

        //! prediction
        bool operator() ( Revision, Revision ) const;

    };

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
